firebase_easy_notify library

Classes

EasyNotify
NotificationModel
NotificationResponse
Details of a Notification Action that was triggered.
PendingNotificationRequest
Details of a pending notification that has not been delivered.
RemoteMessage
A class representing a message sent from Firebase Cloud Messaging.
ScheduleModel

Enums

UserType